# Cion
![Repo Size](https://img.shields.io/github/languages/code-size/meizuflux/cion?style=flat-square)
![Lines of Code](https://img.shields.io/tokei/lines/github/meizuflux/cion?style=flat-square)
![PyPI Downloads](https://img.shields.io/pypi/dm/cion?style=flat-square)
![License](https://img.shields.io/pypi/l/cion?style=flat-square)
![Version](https://img.shields.io/pypi/v/cion?style=flat-square)
![Format](https://img.shields.io/pypi/format/cion?style=flat-square)
![Python Versions](https://img.shields.io/pypi/pyversions/cion?style=flat-square)
![Commit Activity](https://img.shields.io/github/commit-activity/m/meizuflux/cion?style=flat-square)

Cion is a minimal data validation library. It is unopinionated about how you get the input and what you do with the output.

## Installation
**Requires Python 3.10 or greater**
```bash
pip install cion
```

## Usage

View the [examples](/examples) directory and the [tests](/tests) directory for examples on how to use Cion

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)